@@ -1,9 +1,12 @@
+import datetime
+import logging
 import os
 from pathlib import Path
-from typing import Dict, Sequence, Tuple
+from typing import Dict, List, Optional, Tuple
 
 import sentry_sdk
 from sentry_sdk.integrations import Integration
+from sentry_sdk.integrations.logging import LoggingIntegration
 
 _robotoff_instance = os.environ.get("ROBOTOFF_INSTANCE", "dev")
 
@@ -98,7 +101,7 @@ _off_password = os.environ.get("OFF_PASSWORD", "")
 _off_user = os.environ.get("OFF_USER", "")
 
 
-def off_credentials() -> Dict:
+def off_credentials() -> Dict[str, str]:
     return {"user_id": _off_user, "password": _off_password}
 
 
@@ -179,8 +182,15 @@ def slack_token() -> str:
 _sentry_dsn = os.environ.get("SENTRY_DSN")
 
 
-def init_sentry(integrations: Sequence[Integration] = ()):
+def init_sentry(integrations: Optional[List[Integration]] = None):
     if _sentry_dsn:
+        integrations = integrations or []
+        integrations.append(
+            LoggingIntegration(
+                level=logging.INFO,  # Capture info and above as breadcrumbs
+                event_level=logging.WARNING,  # Send warning and errors as events
+            )
+        )
         sentry_sdk.init(
             _sentry_dsn,
             environment=_robotoff_instance,
@@ -254,3 +264,17 @@ INFLUXDB_PASSWORD = os.environ.get("INFLUXDB_PASSWORD")
 
 TEST_DIR = PROJECT_DIR / "tests"
 TEST_DATA_DIR = TEST_DIR / "unit/data"
+
+# Maximum interval between the upload of the insight image and the upload of
+# the most recent image of the product to consider the insight image as
+# trustworthy. Insights with untrustworthy images cannot be applied
+# automatically.
+# For example if days=120, it means that an insight based on an image that is
+# more than 120 days older than the most recent product image cannot be applied
+# automatically.
+IMAGE_MAX_TIMEDELTA = datetime.timedelta(days=120)
+
+# Number of minutes to wait before processing an insight automatically
+INSIGHT_AUTOMATIC_PROCESSING_WAIT = int(
+    os.environ.get("INSIGHT_AUTOMATIC_PROCESSING_WAIT", 10)
+)
